@@ -54,7 +54,7 @@ def snowpark_create(
     if env_conf is None:
         print(
             f"""The {environment} environment is not configured in app.toml
-            yet, please run `snow configure {environment}` first before
+            yet, please run `snow configure -e {environment}` first before
             continuing.""",
         )
         raise typer.Abort()
@@ -254,7 +254,8 @@ def snowpark_update(
                     role=env_conf["role"],
                 )
             print(
-                f"{deploy_response} uploaded to stage " f'{deploy_dict["full_path"]}',
+                f"{deploy_response[0]} uploaded to stage "
+                f'{deploy_dict["full_path"]}',
             )
 
             if updatedPackageList or replace:
@@ -397,7 +398,7 @@ def snowpark_execute(type: str, environment: str, select: str):
     if env_conf is None:
         print(
             f"The {environment} environment is not configured in app.toml "
-            "yet, please run `snow configure dev` first before continuing.",
+            "yet, please run `snow configure -e dev` first before continuing.",
         )
         raise typer.Abort()
     if config.isAuth():
@@ -434,7 +435,7 @@ def snowpark_describe(
     if env_conf is None:
         print(
             "The {environment} environment is not configured in app.toml yet, "
-            "please run `snow configure dev` first before continuing.",
+            "please run `snow configure -e dev` first before continuing.",
         )
         raise typer.Abort()
 
@@ -478,7 +479,7 @@ def snowpark_list(type, environment, like):
     if env_conf is None:
         print(
             f"The {environment} environment is not configured in app.toml "
-            f"yet, please run `snow configure dev` first before continuing.",
+            f"yet, please run `snow configure -e dev` first before continuing.",
         )
         raise typer.Abort()
     if config.isAuth():
@@ -515,7 +516,7 @@ def snowpark_drop(
     if env_conf is None:
         print(
             "The {environment} environment is not configured in app.toml "
-            "yet, please run `snow configure dev` first before continuing.",
+            "yet, please run `snow configure -e dev` first before continuing.",
         )
         raise typer.Abort()
 
