@@ -3,4 +3,4 @@ use warehouse {warehouse};
 use database {database};
 use schema {schema};
 
-put file://{path} @{name} auto_compress=false;
+put file://{path} @{name} auto_compress=false parallel={parallel} overwrite={overwrite};
